<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>Misc</name>
    <message>
        <location filename="../Misc.js" line="+60"/>
        <source>Misc Tools</source>
        <translation>Różne narzędzia</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Show misc tools</source>
        <translation>Wyświetla różne narzędzia</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Misc</source>
        <translation>Różne</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>&amp;Misc</source>
        <translation>Róż&amp;ne</translation>
    </message>
</context>
</TS>
